tracker

package
v0.0.0-...-a618c29 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 1, 2026 License: AGPL-3.0 Imports: 4 Imported by: 0

Documentation

Index

Constants

const (
	// Label holds the string label denoting the tracker type in the database.
	Label = "tracker"
	// FieldID holds the string denoting the id field in the database.
	FieldID = "id"
	// FieldTrackerID holds the string denoting the tracker_id field in the database.
	FieldTrackerID = "tracker_id"
	// FieldProvider holds the string denoting the provider field in the database.
	FieldProvider = "provider"
	// FieldStatus holds the string denoting the status field in the database.
	FieldStatus = "status"
	// FieldScore holds the string denoting the score field in the database.
	FieldScore = "score"
	// FieldProgress holds the string denoting the progress field in the database.
	FieldProgress = "progress"
	// FieldTotalProgress holds the string denoting the total_progress field in the database.
	FieldTotalProgress = "total_progress"
	// FieldStartDate holds the string denoting the start_date field in the database.
	FieldStartDate = "start_date"
	// FieldFinishDate holds the string denoting the finish_date field in the database.
	FieldFinishDate = "finish_date"
	// EdgeDetails holds the string denoting the details edge name in mutations.
	EdgeDetails = "details"
	// Table holds the table name of the tracker in the database.
	Table = "trackers"
	// DetailsTable is the table that holds the details relation/edge. The primary key declared below.
	DetailsTable = "detail_trackers"
	// DetailsInverseTable is the table name for the Detail entity.
	// It exists in this package in order to avoid circular dependency with the "detail" package.
	DetailsInverseTable = "details"
)

Variables

var (
	// TrackerIDValidator is a validator for the "tracker_id" field. It is called by the builders before save.
	TrackerIDValidator func(string) error
	// StatusValidator is a validator for the "status" field. It is called by the builders before save.
	StatusValidator func(string) error
)

Columns holds all SQL columns for tracker fields.

var (
	// DetailsPrimaryKey and DetailsColumn2 are the table columns denoting the
	// primary key for the details relation (M2M).
	DetailsPrimaryKey = []string{"detail_id", "tracker_id"}
)

Functions

func And

func And(predicates ...predicate.Tracker) predicate.Tracker

And groups predicates with the AND operator between them.

func FinishDate

func FinishDate(v int64) predicate.Tracker

FinishDate applies equality check predicate on the "finish_date" field. It's identical to FinishDateEQ.

func FinishDateEQ

func FinishDateEQ(v int64) predicate.Tracker

FinishDateEQ applies the EQ predicate on the "finish_date" field.

func FinishDateGT

func FinishDateGT(v int64) predicate.Tracker

FinishDateGT applies the GT predicate on the "finish_date" field.

func FinishDateGTE

func FinishDateGTE(v int64) predicate.Tracker

FinishDateGTE applies the GTE predicate on the "finish_date" field.

func FinishDateIn

func FinishDateIn(vs ...int64) predicate.Tracker

FinishDateIn applies the In predicate on the "finish_date" field.

func FinishDateIsNil

func FinishDateIsNil() predicate.Tracker

FinishDateIsNil applies the IsNil predicate on the "finish_date" field.

func FinishDateLT

func FinishDateLT(v int64) predicate.Tracker

FinishDateLT applies the LT predicate on the "finish_date" field.

func FinishDateLTE

func FinishDateLTE(v int64) predicate.Tracker

FinishDateLTE applies the LTE predicate on the "finish_date" field.

func FinishDateNEQ

func FinishDateNEQ(v int64) predicate.Tracker

FinishDateNEQ applies the NEQ predicate on the "finish_date" field.

func FinishDateNotIn

func FinishDateNotIn(vs ...int64) predicate.Tracker

FinishDateNotIn applies the NotIn predicate on the "finish_date" field.

func FinishDateNotNil

func FinishDateNotNil() predicate.Tracker

FinishDateNotNil applies the NotNil predicate on the "finish_date" field.

func HasDetails

func HasDetails() predicate.Tracker

HasDetails applies the HasEdge predicate on the "details" edge.

func HasDetailsWith

func HasDetailsWith(preds ...predicate.Detail) predicate.Tracker

HasDetailsWith applies the HasEdge predicate on the "details" edge with a given conditions (other predicates).

func ID

func ID(id int) predicate.Tracker

ID filters vertices based on their ID field.

func IDEQ

func IDEQ(id int) predicate.Tracker

IDEQ applies the EQ predicate on the ID field.

func IDGT

func IDGT(id int) predicate.Tracker

IDGT applies the GT predicate on the ID field.

func IDGTE

func IDGTE(id int) predicate.Tracker

IDGTE applies the GTE predicate on the ID field.

func IDIn

func IDIn(ids ...int) predicate.Tracker

IDIn applies the In predicate on the ID field.

func IDLT

func IDLT(id int) predicate.Tracker

IDLT applies the LT predicate on the ID field.

func IDLTE

func IDLTE(id int) predicate.Tracker

IDLTE applies the LTE predicate on the ID field.

func IDNEQ

func IDNEQ(id int) predicate.Tracker

IDNEQ applies the NEQ predicate on the ID field.

func IDNotIn

func IDNotIn(ids ...int) predicate.Tracker

IDNotIn applies the NotIn predicate on the ID field.

func Not

Not applies the not operator on the given predicate.

func Or

func Or(predicates ...predicate.Tracker) predicate.Tracker

Or groups predicates with the OR operator between them.

func Progress

func Progress(v int) predicate.Tracker

Progress applies equality check predicate on the "progress" field. It's identical to ProgressEQ.

func ProgressEQ

func ProgressEQ(v int) predicate.Tracker

ProgressEQ applies the EQ predicate on the "progress" field.

func ProgressGT

func ProgressGT(v int) predicate.Tracker

ProgressGT applies the GT predicate on the "progress" field.

func ProgressGTE

func ProgressGTE(v int) predicate.Tracker

ProgressGTE applies the GTE predicate on the "progress" field.

func ProgressIn

func ProgressIn(vs ...int) predicate.Tracker

ProgressIn applies the In predicate on the "progress" field.

func ProgressLT

func ProgressLT(v int) predicate.Tracker

ProgressLT applies the LT predicate on the "progress" field.

func ProgressLTE

func ProgressLTE(v int) predicate.Tracker

ProgressLTE applies the LTE predicate on the "progress" field.

func ProgressNEQ

func ProgressNEQ(v int) predicate.Tracker

ProgressNEQ applies the NEQ predicate on the "progress" field.

func ProgressNotIn

func ProgressNotIn(vs ...int) predicate.Tracker

ProgressNotIn applies the NotIn predicate on the "progress" field.

func ProviderEQ

func ProviderEQ(v Provider) predicate.Tracker

ProviderEQ applies the EQ predicate on the "provider" field.

func ProviderIn

func ProviderIn(vs ...Provider) predicate.Tracker

ProviderIn applies the In predicate on the "provider" field.

func ProviderNEQ

func ProviderNEQ(v Provider) predicate.Tracker

ProviderNEQ applies the NEQ predicate on the "provider" field.

func ProviderNotIn

func ProviderNotIn(vs ...Provider) predicate.Tracker

ProviderNotIn applies the NotIn predicate on the "provider" field.

func ProviderValidator

func ProviderValidator(pr Provider) error

ProviderValidator is a validator for the "provider" field enum values. It is called by the builders before save.

func Score

func Score(v int) predicate.Tracker

Score applies equality check predicate on the "score" field. It's identical to ScoreEQ.

func ScoreEQ

func ScoreEQ(v int) predicate.Tracker

ScoreEQ applies the EQ predicate on the "score" field.

func ScoreGT

func ScoreGT(v int) predicate.Tracker

ScoreGT applies the GT predicate on the "score" field.

func ScoreGTE

func ScoreGTE(v int) predicate.Tracker

ScoreGTE applies the GTE predicate on the "score" field.

func ScoreIn

func ScoreIn(vs ...int) predicate.Tracker

ScoreIn applies the In predicate on the "score" field.

func ScoreIsNil

func ScoreIsNil() predicate.Tracker

ScoreIsNil applies the IsNil predicate on the "score" field.

func ScoreLT

func ScoreLT(v int) predicate.Tracker

ScoreLT applies the LT predicate on the "score" field.

func ScoreLTE

func ScoreLTE(v int) predicate.Tracker

ScoreLTE applies the LTE predicate on the "score" field.

func ScoreNEQ

func ScoreNEQ(v int) predicate.Tracker

ScoreNEQ applies the NEQ predicate on the "score" field.

func ScoreNotIn

func ScoreNotIn(vs ...int) predicate.Tracker

ScoreNotIn applies the NotIn predicate on the "score" field.

func ScoreNotNil

func ScoreNotNil() predicate.Tracker

ScoreNotNil applies the NotNil predicate on the "score" field.

func StartDate

func StartDate(v int64) predicate.Tracker

StartDate applies equality check predicate on the "start_date" field. It's identical to StartDateEQ.

func StartDateEQ

func StartDateEQ(v int64) predicate.Tracker

StartDateEQ applies the EQ predicate on the "start_date" field.

func StartDateGT

func StartDateGT(v int64) predicate.Tracker

StartDateGT applies the GT predicate on the "start_date" field.

func StartDateGTE

func StartDateGTE(v int64) predicate.Tracker

StartDateGTE applies the GTE predicate on the "start_date" field.

func StartDateIn

func StartDateIn(vs ...int64) predicate.Tracker

StartDateIn applies the In predicate on the "start_date" field.

func StartDateIsNil

func StartDateIsNil() predicate.Tracker

StartDateIsNil applies the IsNil predicate on the "start_date" field.

func StartDateLT

func StartDateLT(v int64) predicate.Tracker

StartDateLT applies the LT predicate on the "start_date" field.

func StartDateLTE

func StartDateLTE(v int64) predicate.Tracker

StartDateLTE applies the LTE predicate on the "start_date" field.

func StartDateNEQ

func StartDateNEQ(v int64) predicate.Tracker

StartDateNEQ applies the NEQ predicate on the "start_date" field.

func StartDateNotIn

func StartDateNotIn(vs ...int64) predicate.Tracker

StartDateNotIn applies the NotIn predicate on the "start_date" field.

func StartDateNotNil

func StartDateNotNil() predicate.Tracker

StartDateNotNil applies the NotNil predicate on the "start_date" field.

func Status

func Status(v string) predicate.Tracker

Status applies equality check predicate on the "status" field. It's identical to StatusEQ.

func StatusContains

func StatusContains(v string) predicate.Tracker

StatusContains applies the Contains predicate on the "status" field.

func StatusContainsFold

func StatusContainsFold(v string) predicate.Tracker

StatusContainsFold applies the ContainsFold predicate on the "status" field.

func StatusEQ

func StatusEQ(v string) predicate.Tracker

StatusEQ applies the EQ predicate on the "status" field.

func StatusEqualFold

func StatusEqualFold(v string) predicate.Tracker

StatusEqualFold applies the EqualFold predicate on the "status" field.

func StatusGT

func StatusGT(v string) predicate.Tracker

StatusGT applies the GT predicate on the "status" field.

func StatusGTE

func StatusGTE(v string) predicate.Tracker

StatusGTE applies the GTE predicate on the "status" field.

func StatusHasPrefix

func StatusHasPrefix(v string) predicate.Tracker

StatusHasPrefix applies the HasPrefix predicate on the "status" field.

func StatusHasSuffix

func StatusHasSuffix(v string) predicate.Tracker

StatusHasSuffix applies the HasSuffix predicate on the "status" field.

func StatusIn

func StatusIn(vs ...string) predicate.Tracker

StatusIn applies the In predicate on the "status" field.

func StatusLT

func StatusLT(v string) predicate.Tracker

StatusLT applies the LT predicate on the "status" field.

func StatusLTE

func StatusLTE(v string) predicate.Tracker

StatusLTE applies the LTE predicate on the "status" field.

func StatusNEQ

func StatusNEQ(v string) predicate.Tracker

StatusNEQ applies the NEQ predicate on the "status" field.

func StatusNotIn

func StatusNotIn(vs ...string) predicate.Tracker

StatusNotIn applies the NotIn predicate on the "status" field.

func TotalProgress

func TotalProgress(v int) predicate.Tracker

TotalProgress applies equality check predicate on the "total_progress" field. It's identical to TotalProgressEQ.

func TotalProgressEQ

func TotalProgressEQ(v int) predicate.Tracker

TotalProgressEQ applies the EQ predicate on the "total_progress" field.

func TotalProgressGT

func TotalProgressGT(v int) predicate.Tracker

TotalProgressGT applies the GT predicate on the "total_progress" field.

func TotalProgressGTE

func TotalProgressGTE(v int) predicate.Tracker

TotalProgressGTE applies the GTE predicate on the "total_progress" field.

func TotalProgressIn

func TotalProgressIn(vs ...int) predicate.Tracker

TotalProgressIn applies the In predicate on the "total_progress" field.

func TotalProgressIsNil

func TotalProgressIsNil() predicate.Tracker

TotalProgressIsNil applies the IsNil predicate on the "total_progress" field.

func TotalProgressLT

func TotalProgressLT(v int) predicate.Tracker

TotalProgressLT applies the LT predicate on the "total_progress" field.

func TotalProgressLTE

func TotalProgressLTE(v int) predicate.Tracker

TotalProgressLTE applies the LTE predicate on the "total_progress" field.

func TotalProgressNEQ

func TotalProgressNEQ(v int) predicate.Tracker

TotalProgressNEQ applies the NEQ predicate on the "total_progress" field.

func TotalProgressNotIn

func TotalProgressNotIn(vs ...int) predicate.Tracker

TotalProgressNotIn applies the NotIn predicate on the "total_progress" field.

func TotalProgressNotNil

func TotalProgressNotNil() predicate.Tracker

TotalProgressNotNil applies the NotNil predicate on the "total_progress" field.

func TrackerID

func TrackerID(v string) predicate.Tracker

TrackerID applies equality check predicate on the "tracker_id" field. It's identical to TrackerIDEQ.

func TrackerIDContains

func TrackerIDContains(v string) predicate.Tracker

TrackerIDContains applies the Contains predicate on the "tracker_id" field.

func TrackerIDContainsFold

func TrackerIDContainsFold(v string) predicate.Tracker

TrackerIDContainsFold applies the ContainsFold predicate on the "tracker_id" field.

func TrackerIDEQ

func TrackerIDEQ(v string) predicate.Tracker

TrackerIDEQ applies the EQ predicate on the "tracker_id" field.

func TrackerIDEqualFold

func TrackerIDEqualFold(v string) predicate.Tracker

TrackerIDEqualFold applies the EqualFold predicate on the "tracker_id" field.

func TrackerIDGT

func TrackerIDGT(v string) predicate.Tracker

TrackerIDGT applies the GT predicate on the "tracker_id" field.

func TrackerIDGTE

func TrackerIDGTE(v string) predicate.Tracker

TrackerIDGTE applies the GTE predicate on the "tracker_id" field.

func TrackerIDHasPrefix

func TrackerIDHasPrefix(v string) predicate.Tracker

TrackerIDHasPrefix applies the HasPrefix predicate on the "tracker_id" field.

func TrackerIDHasSuffix

func TrackerIDHasSuffix(v string) predicate.Tracker

TrackerIDHasSuffix applies the HasSuffix predicate on the "tracker_id" field.

func TrackerIDIn

func TrackerIDIn(vs ...string) predicate.Tracker

TrackerIDIn applies the In predicate on the "tracker_id" field.

func TrackerIDLT

func TrackerIDLT(v string) predicate.Tracker

TrackerIDLT applies the LT predicate on the "tracker_id" field.

func TrackerIDLTE

func TrackerIDLTE(v string) predicate.Tracker

TrackerIDLTE applies the LTE predicate on the "tracker_id" field.

func TrackerIDNEQ

func TrackerIDNEQ(v string) predicate.Tracker

TrackerIDNEQ applies the NEQ predicate on the "tracker_id" field.

func TrackerIDNotIn

func TrackerIDNotIn(vs ...string) predicate.Tracker

TrackerIDNotIn applies the NotIn predicate on the "tracker_id" field.

func ValidColumn

func ValidColumn(column string) bool

ValidColumn reports if the column name is valid (part of the table columns).

Types

type OrderOption

type OrderOption func(*sql.Selector)

OrderOption defines the ordering options for the Tracker queries.

func ByDetails

func ByDetails(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption

ByDetails orders the results by details terms.

func ByDetailsCount

func ByDetailsCount(opts ...sql.OrderTermOption) OrderOption

ByDetailsCount orders the results by details count.

func ByFinishDate

func ByFinishDate(opts ...sql.OrderTermOption) OrderOption

ByFinishDate orders the results by the finish_date field.

func ByID

func ByID(opts ...sql.OrderTermOption) OrderOption

ByID orders the results by the id field.

func ByProgress

func ByProgress(opts ...sql.OrderTermOption) OrderOption

ByProgress orders the results by the progress field.

func ByProvider

func ByProvider(opts ...sql.OrderTermOption) OrderOption

ByProvider orders the results by the provider field.

func ByScore

func ByScore(opts ...sql.OrderTermOption) OrderOption

ByScore orders the results by the score field.

func ByStartDate

func ByStartDate(opts ...sql.OrderTermOption) OrderOption

ByStartDate orders the results by the start_date field.

func ByStatus

func ByStatus(opts ...sql.OrderTermOption) OrderOption

ByStatus orders the results by the status field.

func ByTotalProgress

func ByTotalProgress(opts ...sql.OrderTermOption) OrderOption

ByTotalProgress orders the results by the total_progress field.

func ByTrackerID

func ByTrackerID(opts ...sql.OrderTermOption) OrderOption

ByTrackerID orders the results by the tracker_id field.

type Provider

type Provider string

Provider defines the type for the "provider" enum field.

const (
	ProviderAnilist     Provider = "anilist"
	ProviderMyanimelist Provider = "myanimelist"
	ProviderKitsu       Provider = "kitsu"
	ProviderTmdb        Provider = "tmdb"
)

Provider values.

func (Provider) String

func (pr Provider) String() string

Jump to