Documentation
¶
Index ¶
- Constants
- Variables
- func And(predicates ...predicate.AppSetting) predicate.AppSetting
- func ID(id int) predicate.AppSetting
- func IDEQ(id int) predicate.AppSetting
- func IDGT(id int) predicate.AppSetting
- func IDGTE(id int) predicate.AppSetting
- func IDIn(ids ...int) predicate.AppSetting
- func IDLT(id int) predicate.AppSetting
- func IDLTE(id int) predicate.AppSetting
- func IDNEQ(id int) predicate.AppSetting
- func IDNotIn(ids ...int) predicate.AppSetting
- func Key(v string) predicate.AppSetting
- func KeyContains(v string) predicate.AppSetting
- func KeyContainsFold(v string) predicate.AppSetting
- func KeyEQ(v string) predicate.AppSetting
- func KeyEqualFold(v string) predicate.AppSetting
- func KeyGT(v string) predicate.AppSetting
- func KeyGTE(v string) predicate.AppSetting
- func KeyHasPrefix(v string) predicate.AppSetting
- func KeyHasSuffix(v string) predicate.AppSetting
- func KeyIn(vs ...string) predicate.AppSetting
- func KeyLT(v string) predicate.AppSetting
- func KeyLTE(v string) predicate.AppSetting
- func KeyNEQ(v string) predicate.AppSetting
- func KeyNotIn(vs ...string) predicate.AppSetting
- func Not(p predicate.AppSetting) predicate.AppSetting
- func Or(predicates ...predicate.AppSetting) predicate.AppSetting
- func ValidColumn(column string) bool
- func Value(v string) predicate.AppSetting
- func ValueContains(v string) predicate.AppSetting
- func ValueContainsFold(v string) predicate.AppSetting
- func ValueEQ(v string) predicate.AppSetting
- func ValueEqualFold(v string) predicate.AppSetting
- func ValueGT(v string) predicate.AppSetting
- func ValueGTE(v string) predicate.AppSetting
- func ValueHasPrefix(v string) predicate.AppSetting
- func ValueHasSuffix(v string) predicate.AppSetting
- func ValueIn(vs ...string) predicate.AppSetting
- func ValueLT(v string) predicate.AppSetting
- func ValueLTE(v string) predicate.AppSetting
- func ValueNEQ(v string) predicate.AppSetting
- func ValueNotIn(vs ...string) predicate.AppSetting
- type OrderOption
Constants ¶
const ( // Label holds the string label denoting the appsetting type in the database. Label = "app_setting" // FieldID holds the string denoting the id field in the database. FieldID = "id" // FieldKey holds the string denoting the key field in the database. FieldKey = "key" // FieldValue holds the string denoting the value field in the database. FieldValue = "value" // Table holds the table name of the appsetting in the database. Table = "app_settings" )
Variables ¶
var Columns = []string{ FieldID, FieldKey, FieldValue, }
Columns holds all SQL columns for appsetting fields.
var ( // KeyValidator is a validator for the "key" field. It is called by the builders before save. KeyValidator func(string) error )
Functions ¶
func And ¶
func And(predicates ...predicate.AppSetting) predicate.AppSetting
And groups predicates with the AND operator between them.
func IDGTE ¶
func IDGTE(id int) predicate.AppSetting
IDGTE applies the GTE predicate on the ID field.
func IDIn ¶
func IDIn(ids ...int) predicate.AppSetting
IDIn applies the In predicate on the ID field.
func IDLTE ¶
func IDLTE(id int) predicate.AppSetting
IDLTE applies the LTE predicate on the ID field.
func IDNEQ ¶
func IDNEQ(id int) predicate.AppSetting
IDNEQ applies the NEQ predicate on the ID field.
func IDNotIn ¶
func IDNotIn(ids ...int) predicate.AppSetting
IDNotIn applies the NotIn predicate on the ID field.
func Key ¶
func Key(v string) predicate.AppSetting
Key applies equality check predicate on the "key" field. It's identical to KeyEQ.
func KeyContains ¶
func KeyContains(v string) predicate.AppSetting
KeyContains applies the Contains predicate on the "key" field.
func KeyContainsFold ¶
func KeyContainsFold(v string) predicate.AppSetting
KeyContainsFold applies the ContainsFold predicate on the "key" field.
func KeyEQ ¶
func KeyEQ(v string) predicate.AppSetting
KeyEQ applies the EQ predicate on the "key" field.
func KeyEqualFold ¶
func KeyEqualFold(v string) predicate.AppSetting
KeyEqualFold applies the EqualFold predicate on the "key" field.
func KeyGT ¶
func KeyGT(v string) predicate.AppSetting
KeyGT applies the GT predicate on the "key" field.
func KeyGTE ¶
func KeyGTE(v string) predicate.AppSetting
KeyGTE applies the GTE predicate on the "key" field.
func KeyHasPrefix ¶
func KeyHasPrefix(v string) predicate.AppSetting
KeyHasPrefix applies the HasPrefix predicate on the "key" field.
func KeyHasSuffix ¶
func KeyHasSuffix(v string) predicate.AppSetting
KeyHasSuffix applies the HasSuffix predicate on the "key" field.
func KeyIn ¶
func KeyIn(vs ...string) predicate.AppSetting
KeyIn applies the In predicate on the "key" field.
func KeyLT ¶
func KeyLT(v string) predicate.AppSetting
KeyLT applies the LT predicate on the "key" field.
func KeyLTE ¶
func KeyLTE(v string) predicate.AppSetting
KeyLTE applies the LTE predicate on the "key" field.
func KeyNEQ ¶
func KeyNEQ(v string) predicate.AppSetting
KeyNEQ applies the NEQ predicate on the "key" field.
func KeyNotIn ¶
func KeyNotIn(vs ...string) predicate.AppSetting
KeyNotIn applies the NotIn predicate on the "key" field.
func Not ¶
func Not(p predicate.AppSetting) predicate.AppSetting
Not applies the not operator on the given predicate.
func Or ¶
func Or(predicates ...predicate.AppSetting) predicate.AppSetting
Or groups predicates with the OR operator between them.
func ValidColumn ¶
ValidColumn reports if the column name is valid (part of the table columns).
func Value ¶
func Value(v string) predicate.AppSetting
Value applies equality check predicate on the "value" field. It's identical to ValueEQ.
func ValueContains ¶
func ValueContains(v string) predicate.AppSetting
ValueContains applies the Contains predicate on the "value" field.
func ValueContainsFold ¶
func ValueContainsFold(v string) predicate.AppSetting
ValueContainsFold applies the ContainsFold predicate on the "value" field.
func ValueEQ ¶
func ValueEQ(v string) predicate.AppSetting
ValueEQ applies the EQ predicate on the "value" field.
func ValueEqualFold ¶
func ValueEqualFold(v string) predicate.AppSetting
ValueEqualFold applies the EqualFold predicate on the "value" field.
func ValueGT ¶
func ValueGT(v string) predicate.AppSetting
ValueGT applies the GT predicate on the "value" field.
func ValueGTE ¶
func ValueGTE(v string) predicate.AppSetting
ValueGTE applies the GTE predicate on the "value" field.
func ValueHasPrefix ¶
func ValueHasPrefix(v string) predicate.AppSetting
ValueHasPrefix applies the HasPrefix predicate on the "value" field.
func ValueHasSuffix ¶
func ValueHasSuffix(v string) predicate.AppSetting
ValueHasSuffix applies the HasSuffix predicate on the "value" field.
func ValueIn ¶
func ValueIn(vs ...string) predicate.AppSetting
ValueIn applies the In predicate on the "value" field.
func ValueLT ¶
func ValueLT(v string) predicate.AppSetting
ValueLT applies the LT predicate on the "value" field.
func ValueLTE ¶
func ValueLTE(v string) predicate.AppSetting
ValueLTE applies the LTE predicate on the "value" field.
func ValueNEQ ¶
func ValueNEQ(v string) predicate.AppSetting
ValueNEQ applies the NEQ predicate on the "value" field.
func ValueNotIn ¶
func ValueNotIn(vs ...string) predicate.AppSetting
ValueNotIn applies the NotIn predicate on the "value" field.
Types ¶
type OrderOption ¶
OrderOption defines the ordering options for the AppSetting queries.
func ByID ¶
func ByID(opts ...sql.OrderTermOption) OrderOption
ByID orders the results by the id field.
func ByKey ¶
func ByKey(opts ...sql.OrderTermOption) OrderOption
ByKey orders the results by the key field.
func ByValue ¶
func ByValue(opts ...sql.OrderTermOption) OrderOption
ByValue orders the results by the value field.