Documentation
¶
Index ¶
- Constants
- Variables
- func And(predicates ...predicate.Tracker) predicate.Tracker
- func FinishDate(v int64) predicate.Tracker
- func FinishDateEQ(v int64) predicate.Tracker
- func FinishDateGT(v int64) predicate.Tracker
- func FinishDateGTE(v int64) predicate.Tracker
- func FinishDateIn(vs ...int64) predicate.Tracker
- func FinishDateIsNil() predicate.Tracker
- func FinishDateLT(v int64) predicate.Tracker
- func FinishDateLTE(v int64) predicate.Tracker
- func FinishDateNEQ(v int64) predicate.Tracker
- func FinishDateNotIn(vs ...int64) predicate.Tracker
- func FinishDateNotNil() predicate.Tracker
- func HasDetails() predicate.Tracker
- func HasDetailsWith(preds ...predicate.Detail) predicate.Tracker
- func ID(id int) predicate.Tracker
- func IDEQ(id int) predicate.Tracker
- func IDGT(id int) predicate.Tracker
- func IDGTE(id int) predicate.Tracker
- func IDIn(ids ...int) predicate.Tracker
- func IDLT(id int) predicate.Tracker
- func IDLTE(id int) predicate.Tracker
- func IDNEQ(id int) predicate.Tracker
- func IDNotIn(ids ...int) predicate.Tracker
- func Not(p predicate.Tracker) predicate.Tracker
- func Or(predicates ...predicate.Tracker) predicate.Tracker
- func Progress(v int) predicate.Tracker
- func ProgressEQ(v int) predicate.Tracker
- func ProgressGT(v int) predicate.Tracker
- func ProgressGTE(v int) predicate.Tracker
- func ProgressIn(vs ...int) predicate.Tracker
- func ProgressLT(v int) predicate.Tracker
- func ProgressLTE(v int) predicate.Tracker
- func ProgressNEQ(v int) predicate.Tracker
- func ProgressNotIn(vs ...int) predicate.Tracker
- func ProviderEQ(v Provider) predicate.Tracker
- func ProviderIn(vs ...Provider) predicate.Tracker
- func ProviderNEQ(v Provider) predicate.Tracker
- func ProviderNotIn(vs ...Provider) predicate.Tracker
- func ProviderValidator(pr Provider) error
- func Score(v int) predicate.Tracker
- func ScoreEQ(v int) predicate.Tracker
- func ScoreGT(v int) predicate.Tracker
- func ScoreGTE(v int) predicate.Tracker
- func ScoreIn(vs ...int) predicate.Tracker
- func ScoreIsNil() predicate.Tracker
- func ScoreLT(v int) predicate.Tracker
- func ScoreLTE(v int) predicate.Tracker
- func ScoreNEQ(v int) predicate.Tracker
- func ScoreNotIn(vs ...int) predicate.Tracker
- func ScoreNotNil() predicate.Tracker
- func StartDate(v int64) predicate.Tracker
- func StartDateEQ(v int64) predicate.Tracker
- func StartDateGT(v int64) predicate.Tracker
- func StartDateGTE(v int64) predicate.Tracker
- func StartDateIn(vs ...int64) predicate.Tracker
- func StartDateIsNil() predicate.Tracker
- func StartDateLT(v int64) predicate.Tracker
- func StartDateLTE(v int64) predicate.Tracker
- func StartDateNEQ(v int64) predicate.Tracker
- func StartDateNotIn(vs ...int64) predicate.Tracker
- func StartDateNotNil() predicate.Tracker
- func Status(v string) predicate.Tracker
- func StatusContains(v string) predicate.Tracker
- func StatusContainsFold(v string) predicate.Tracker
- func StatusEQ(v string) predicate.Tracker
- func StatusEqualFold(v string) predicate.Tracker
- func StatusGT(v string) predicate.Tracker
- func StatusGTE(v string) predicate.Tracker
- func StatusHasPrefix(v string) predicate.Tracker
- func StatusHasSuffix(v string) predicate.Tracker
- func StatusIn(vs ...string) predicate.Tracker
- func StatusLT(v string) predicate.Tracker
- func StatusLTE(v string) predicate.Tracker
- func StatusNEQ(v string) predicate.Tracker
- func StatusNotIn(vs ...string) predicate.Tracker
- func TotalProgress(v int) predicate.Tracker
- func TotalProgressEQ(v int) predicate.Tracker
- func TotalProgressGT(v int) predicate.Tracker
- func TotalProgressGTE(v int) predicate.Tracker
- func TotalProgressIn(vs ...int) predicate.Tracker
- func TotalProgressIsNil() predicate.Tracker
- func TotalProgressLT(v int) predicate.Tracker
- func TotalProgressLTE(v int) predicate.Tracker
- func TotalProgressNEQ(v int) predicate.Tracker
- func TotalProgressNotIn(vs ...int) predicate.Tracker
- func TotalProgressNotNil() predicate.Tracker
- func TrackerID(v string) predicate.Tracker
- func TrackerIDContains(v string) predicate.Tracker
- func TrackerIDContainsFold(v string) predicate.Tracker
- func TrackerIDEQ(v string) predicate.Tracker
- func TrackerIDEqualFold(v string) predicate.Tracker
- func TrackerIDGT(v string) predicate.Tracker
- func TrackerIDGTE(v string) predicate.Tracker
- func TrackerIDHasPrefix(v string) predicate.Tracker
- func TrackerIDHasSuffix(v string) predicate.Tracker
- func TrackerIDIn(vs ...string) predicate.Tracker
- func TrackerIDLT(v string) predicate.Tracker
- func TrackerIDLTE(v string) predicate.Tracker
- func TrackerIDNEQ(v string) predicate.Tracker
- func TrackerIDNotIn(vs ...string) predicate.Tracker
- func ValidColumn(column string) bool
- type OrderOption
- func ByDetails(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
- func ByDetailsCount(opts ...sql.OrderTermOption) OrderOption
- func ByFinishDate(opts ...sql.OrderTermOption) OrderOption
- func ByID(opts ...sql.OrderTermOption) OrderOption
- func ByProgress(opts ...sql.OrderTermOption) OrderOption
- func ByProvider(opts ...sql.OrderTermOption) OrderOption
- func ByScore(opts ...sql.OrderTermOption) OrderOption
- func ByStartDate(opts ...sql.OrderTermOption) OrderOption
- func ByStatus(opts ...sql.OrderTermOption) OrderOption
- func ByTotalProgress(opts ...sql.OrderTermOption) OrderOption
- func ByTrackerID(opts ...sql.OrderTermOption) OrderOption
- type Provider
Constants ¶
const ( // Label holds the string label denoting the tracker type in the database. Label = "tracker" // FieldID holds the string denoting the id field in the database. FieldID = "id" // FieldTrackerID holds the string denoting the tracker_id field in the database. FieldTrackerID = "tracker_id" // FieldProvider holds the string denoting the provider field in the database. FieldProvider = "provider" // FieldStatus holds the string denoting the status field in the database. FieldStatus = "status" // FieldScore holds the string denoting the score field in the database. FieldScore = "score" // FieldProgress holds the string denoting the progress field in the database. FieldProgress = "progress" // FieldTotalProgress holds the string denoting the total_progress field in the database. FieldTotalProgress = "total_progress" // FieldStartDate holds the string denoting the start_date field in the database. FieldStartDate = "start_date" // FieldFinishDate holds the string denoting the finish_date field in the database. FieldFinishDate = "finish_date" // EdgeDetails holds the string denoting the details edge name in mutations. EdgeDetails = "details" // Table holds the table name of the tracker in the database. Table = "trackers" // DetailsTable is the table that holds the details relation/edge. The primary key declared below. DetailsTable = "detail_trackers" // DetailsInverseTable is the table name for the Detail entity. // It exists in this package in order to avoid circular dependency with the "detail" package. DetailsInverseTable = "details" )
Variables ¶
var ( // TrackerIDValidator is a validator for the "tracker_id" field. It is called by the builders before save. TrackerIDValidator func(string) error // StatusValidator is a validator for the "status" field. It is called by the builders before save. StatusValidator func(string) error )
var Columns = []string{ FieldID, FieldTrackerID, FieldProvider, FieldStatus, FieldScore, FieldProgress, FieldTotalProgress, FieldStartDate, FieldFinishDate, }
Columns holds all SQL columns for tracker fields.
var ( // DetailsPrimaryKey and DetailsColumn2 are the table columns denoting the // primary key for the details relation (M2M). DetailsPrimaryKey = []string{"detail_id", "tracker_id"} )
Functions ¶
func FinishDate ¶
FinishDate applies equality check predicate on the "finish_date" field. It's identical to FinishDateEQ.
func FinishDateEQ ¶
FinishDateEQ applies the EQ predicate on the "finish_date" field.
func FinishDateGT ¶
FinishDateGT applies the GT predicate on the "finish_date" field.
func FinishDateGTE ¶
FinishDateGTE applies the GTE predicate on the "finish_date" field.
func FinishDateIn ¶
FinishDateIn applies the In predicate on the "finish_date" field.
func FinishDateIsNil ¶
FinishDateIsNil applies the IsNil predicate on the "finish_date" field.
func FinishDateLT ¶
FinishDateLT applies the LT predicate on the "finish_date" field.
func FinishDateLTE ¶
FinishDateLTE applies the LTE predicate on the "finish_date" field.
func FinishDateNEQ ¶
FinishDateNEQ applies the NEQ predicate on the "finish_date" field.
func FinishDateNotIn ¶
FinishDateNotIn applies the NotIn predicate on the "finish_date" field.
func FinishDateNotNil ¶
FinishDateNotNil applies the NotNil predicate on the "finish_date" field.
func HasDetails ¶
HasDetails applies the HasEdge predicate on the "details" edge.
func HasDetailsWith ¶
HasDetailsWith applies the HasEdge predicate on the "details" edge with a given conditions (other predicates).
func Progress ¶
Progress applies equality check predicate on the "progress" field. It's identical to ProgressEQ.
func ProgressEQ ¶
ProgressEQ applies the EQ predicate on the "progress" field.
func ProgressGT ¶
ProgressGT applies the GT predicate on the "progress" field.
func ProgressGTE ¶
ProgressGTE applies the GTE predicate on the "progress" field.
func ProgressIn ¶
ProgressIn applies the In predicate on the "progress" field.
func ProgressLT ¶
ProgressLT applies the LT predicate on the "progress" field.
func ProgressLTE ¶
ProgressLTE applies the LTE predicate on the "progress" field.
func ProgressNEQ ¶
ProgressNEQ applies the NEQ predicate on the "progress" field.
func ProgressNotIn ¶
ProgressNotIn applies the NotIn predicate on the "progress" field.
func ProviderEQ ¶
ProviderEQ applies the EQ predicate on the "provider" field.
func ProviderIn ¶
ProviderIn applies the In predicate on the "provider" field.
func ProviderNEQ ¶
ProviderNEQ applies the NEQ predicate on the "provider" field.
func ProviderNotIn ¶
ProviderNotIn applies the NotIn predicate on the "provider" field.
func ProviderValidator ¶
ProviderValidator is a validator for the "provider" field enum values. It is called by the builders before save.
func Score ¶
Score applies equality check predicate on the "score" field. It's identical to ScoreEQ.
func ScoreIsNil ¶
ScoreIsNil applies the IsNil predicate on the "score" field.
func ScoreNotIn ¶
ScoreNotIn applies the NotIn predicate on the "score" field.
func ScoreNotNil ¶
ScoreNotNil applies the NotNil predicate on the "score" field.
func StartDate ¶
StartDate applies equality check predicate on the "start_date" field. It's identical to StartDateEQ.
func StartDateEQ ¶
StartDateEQ applies the EQ predicate on the "start_date" field.
func StartDateGT ¶
StartDateGT applies the GT predicate on the "start_date" field.
func StartDateGTE ¶
StartDateGTE applies the GTE predicate on the "start_date" field.
func StartDateIn ¶
StartDateIn applies the In predicate on the "start_date" field.
func StartDateIsNil ¶
StartDateIsNil applies the IsNil predicate on the "start_date" field.
func StartDateLT ¶
StartDateLT applies the LT predicate on the "start_date" field.
func StartDateLTE ¶
StartDateLTE applies the LTE predicate on the "start_date" field.
func StartDateNEQ ¶
StartDateNEQ applies the NEQ predicate on the "start_date" field.
func StartDateNotIn ¶
StartDateNotIn applies the NotIn predicate on the "start_date" field.
func StartDateNotNil ¶
StartDateNotNil applies the NotNil predicate on the "start_date" field.
func Status ¶
Status applies equality check predicate on the "status" field. It's identical to StatusEQ.
func StatusContains ¶
StatusContains applies the Contains predicate on the "status" field.
func StatusContainsFold ¶
StatusContainsFold applies the ContainsFold predicate on the "status" field.
func StatusEqualFold ¶
StatusEqualFold applies the EqualFold predicate on the "status" field.
func StatusHasPrefix ¶
StatusHasPrefix applies the HasPrefix predicate on the "status" field.
func StatusHasSuffix ¶
StatusHasSuffix applies the HasSuffix predicate on the "status" field.
func StatusNotIn ¶
StatusNotIn applies the NotIn predicate on the "status" field.
func TotalProgress ¶
TotalProgress applies equality check predicate on the "total_progress" field. It's identical to TotalProgressEQ.
func TotalProgressEQ ¶
TotalProgressEQ applies the EQ predicate on the "total_progress" field.
func TotalProgressGT ¶
TotalProgressGT applies the GT predicate on the "total_progress" field.
func TotalProgressGTE ¶
TotalProgressGTE applies the GTE predicate on the "total_progress" field.
func TotalProgressIn ¶
TotalProgressIn applies the In predicate on the "total_progress" field.
func TotalProgressIsNil ¶
TotalProgressIsNil applies the IsNil predicate on the "total_progress" field.
func TotalProgressLT ¶
TotalProgressLT applies the LT predicate on the "total_progress" field.
func TotalProgressLTE ¶
TotalProgressLTE applies the LTE predicate on the "total_progress" field.
func TotalProgressNEQ ¶
TotalProgressNEQ applies the NEQ predicate on the "total_progress" field.
func TotalProgressNotIn ¶
TotalProgressNotIn applies the NotIn predicate on the "total_progress" field.
func TotalProgressNotNil ¶
TotalProgressNotNil applies the NotNil predicate on the "total_progress" field.
func TrackerID ¶
TrackerID applies equality check predicate on the "tracker_id" field. It's identical to TrackerIDEQ.
func TrackerIDContains ¶
TrackerIDContains applies the Contains predicate on the "tracker_id" field.
func TrackerIDContainsFold ¶
TrackerIDContainsFold applies the ContainsFold predicate on the "tracker_id" field.
func TrackerIDEQ ¶
TrackerIDEQ applies the EQ predicate on the "tracker_id" field.
func TrackerIDEqualFold ¶
TrackerIDEqualFold applies the EqualFold predicate on the "tracker_id" field.
func TrackerIDGT ¶
TrackerIDGT applies the GT predicate on the "tracker_id" field.
func TrackerIDGTE ¶
TrackerIDGTE applies the GTE predicate on the "tracker_id" field.
func TrackerIDHasPrefix ¶
TrackerIDHasPrefix applies the HasPrefix predicate on the "tracker_id" field.
func TrackerIDHasSuffix ¶
TrackerIDHasSuffix applies the HasSuffix predicate on the "tracker_id" field.
func TrackerIDIn ¶
TrackerIDIn applies the In predicate on the "tracker_id" field.
func TrackerIDLT ¶
TrackerIDLT applies the LT predicate on the "tracker_id" field.
func TrackerIDLTE ¶
TrackerIDLTE applies the LTE predicate on the "tracker_id" field.
func TrackerIDNEQ ¶
TrackerIDNEQ applies the NEQ predicate on the "tracker_id" field.
func TrackerIDNotIn ¶
TrackerIDNotIn applies the NotIn predicate on the "tracker_id" field.
func ValidColumn ¶
ValidColumn reports if the column name is valid (part of the table columns).
Types ¶
type OrderOption ¶
OrderOption defines the ordering options for the Tracker queries.
func ByDetails ¶
func ByDetails(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
ByDetails orders the results by details terms.
func ByDetailsCount ¶
func ByDetailsCount(opts ...sql.OrderTermOption) OrderOption
ByDetailsCount orders the results by details count.
func ByFinishDate ¶
func ByFinishDate(opts ...sql.OrderTermOption) OrderOption
ByFinishDate orders the results by the finish_date field.
func ByID ¶
func ByID(opts ...sql.OrderTermOption) OrderOption
ByID orders the results by the id field.
func ByProgress ¶
func ByProgress(opts ...sql.OrderTermOption) OrderOption
ByProgress orders the results by the progress field.
func ByProvider ¶
func ByProvider(opts ...sql.OrderTermOption) OrderOption
ByProvider orders the results by the provider field.
func ByScore ¶
func ByScore(opts ...sql.OrderTermOption) OrderOption
ByScore orders the results by the score field.
func ByStartDate ¶
func ByStartDate(opts ...sql.OrderTermOption) OrderOption
ByStartDate orders the results by the start_date field.
func ByStatus ¶
func ByStatus(opts ...sql.OrderTermOption) OrderOption
ByStatus orders the results by the status field.
func ByTotalProgress ¶
func ByTotalProgress(opts ...sql.OrderTermOption) OrderOption
ByTotalProgress orders the results by the total_progress field.
func ByTrackerID ¶
func ByTrackerID(opts ...sql.OrderTermOption) OrderOption
ByTrackerID orders the results by the tracker_id field.